@@ -5,9 +5,10 @@ reV supply curve module
 - Supply Curve creation
 """
 from copy import deepcopy
-import os
+import json
 import logging
 import numpy as np
+import os
 import pandas as pd
 from warnings import warn
 
@@ -59,10 +60,7 @@ class SupplyCurve:
         Total LCOE of each supply curve point considering the LCOE friction
         scalar from the aggregation step (mean_lcoe_friction + lcot) ($/MWh).
     """
-    def __init__(self, sc_points, trans_table, fcr, sc_features=None,
-                 transmission_costs=None, avail_cap_frac=1,
-                 line_limited=False, connectable=True, max_workers=None,
-                 consider_friction=True):
+    def __init__(self, sc_points, trans_table, sc_features=None):
         """
         Parameters
         ----------
@@ -73,59 +71,19 @@ class SupplyCurve:
             Path to .csv or .json or DataFrame containing supply curve
             transmission mapping, can also be a list of transmission tables
             with different line voltage (capacity) ratings.
-        fcr : float
-            Fixed charge rate, used to compute LCOT
         sc_features : str | pandas.DataFrame, optional
             Path to .csv or .json or DataFrame containing additional supply
             curve features, e.g. transmission multipliers, regions,
             by default None
-        transmission_costs : str | dict, optional
-            Transmission feature costs to use with TransmissionFeatures
-            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
-            center_tie_in_cost, sink_tie_in_cost, by default None
-        avail_cap_frac : int, optional
-            Fraction of transmissions features capacity 'ac_cap' to make
-            available for connection to supply curve points, by default 1
-        line_limited : bool, optional
-            Flag to have substation connection is limited by maximum capacity
-            of the attached lines, legacy method, by default False
-        connectable : bool, optional
-            Flag to only compute tranmission capital cost if transmission
-            feature has enough available capacity, by default True
-        max_workers : int | NoneType, optional
-            Number of workers to use to compute lcot, if > 1 run in parallel.
-            None uses all available cpu's. by default None
-        consider_friction : bool, optional
-            Flag to consider friction layer on LCOE, by default True
         """
         log_versions(logger)
         logger.info('Supply curve points input: {}'.format(sc_points))
         logger.info('Transmission table input: {}'.format(trans_table))
 
-        if transmission_costs is not None:
-            trans_costs = TF._parse_dictionary(transmission_costs)
-        else:
-            trans_costs = {}
-
         self._sc_points = self._parse_sc_points(sc_points,
                                                 sc_features=sc_features)
-        trans_table = self._map_tables(self._sc_points, trans_table)
-        self._trans_table = self._add_trans_lcot(trans_table, fcr,
-                                                 trans_costs=trans_costs,
-                                                 avail_cap_frac=avail_cap_frac,
-                                                 line_limited=line_limited,
-                                                 connectable=connectable,
-                                                 max_workers=max_workers)
-        self._trans_features = self._create_handler(
-            self._trans_table, trans_costs=trans_costs,
-            avail_cap_frac=avail_cap_frac)
-        self._avail_cap_frac = avail_cap_frac
-
-        self._consider_friction = consider_friction
-        self._calculate_total_lcoe_friction()
-
-        out = self._parse_sc_gids(self._trans_table)
-        self._trans_table, self._sc_gids, self._mask = out
+        self._trans_table = self._map_tables(self._sc_points, trans_table)
+        self._sc_gids, self._mask = self._parse_sc_gids(self._trans_table)
 
     def __repr__(self):
         msg = "{} with {} points".format(self.__class__.__name__, len(self))
@@ -295,7 +253,86 @@ class SupplyCurve:
         return trans_sc_table
 
     @staticmethod
-    def _check_sc_trans_table(sc_points, trans_table):
+    def _parse_trans_line_gids(trans_line_gids):
+        """
+        Parse json string of trans_line_gids if needed
+
+        Parameters
+        ----------
+        trans_line_gids : str | list
+            list of transmission line 'trans_gid's, if a json string, convert
+            to list
+
+        Returns
+        -------
+        trans_line_gids : list
+            list of transmission line 'trans_gid's
+        """
+        if isinstance(trans_line_gids, str):
+            trans_line_gids = json.loads(trans_line_gids)
+
+        return trans_line_gids
+
+    @classmethod
+    def _check_sub_trans_lines(cls, features):
+        """
+        Check to make sure all trans-lines are available for all sub-stations
+
+        Parameters
+        ----------
+        features : pandas.DataFrame
+            Table of transmission feature to check substation to transmission
+            line gid connections
+
+        Returns
+        -------
+        line_gids : list
+            List of missing transmission line 'trans_gid's for all substations
+            in features table
+        """
+        mask = features['category'].str.lower() == 'substation'
+        line_gids = \
+            features.loc[mask,
+                         'trans_line_gids'].apply(cls._parse_trans_line_gids)
+
+        line_gids = np.unique(np.concatenate(line_gids.values))
+
+        test = np.isin(line_gids, features['trans_gid'].values)
+
+        return line_gids[~test].tolist()
+
+    @classmethod
+    def _check_substation_conns(cls, trans_table, sc_cols='sc_gid'):
+        """
+        Run checks on substation transmission features to make sure that
+        every sc point connecting to a substation can also connect to its
+        respective transmission lines
+
+        Parameters
+        ----------
+        trans_table : pd.DataFrame
+            Table mapping supply curve points to transmission features
+            (should already be merged with SC points).
+        sc_cols : str | list, optional
+            Column(s) in trans_table with unique supply curve id,
+            by default 'sc_gid'
+        """
+        missing = {}
+        for sc_point, sc_table in trans_table.groupby(sc_cols):
+            tl_gids = cls._check_sub_trans_lines(sc_table)
+            if tl_gids:
+                missing[sc_point] = tl_gids
+
+        if any(missing):
+            msg = ('The following sc_gid (keys) were connected to substations '
+                   'but were not connected to the respective transmission line'
+                   ' gids (values) which is required for full SC sort: {}'
+                   .format(missing))
+            logger.error(msg)
+            raise SupplyCurveInputError(msg)
+
+    @classmethod
+    def _check_sc_trans_table(cls, sc_points, trans_table):
         """Run self checks on sc_points table and the merged trans_table
 
         Parameters
@@ -433,63 +470,6 @@ class SupplyCurve:
 
         return trans_sc_table
 
-    @classmethod
-    def _add_trans_lcot(cls, trans_table, fcr, trans_costs=None,
-                        avail_cap_frac=1, line_limited=False, connectable=True,
-                        max_workers=None):
-        """Compute LCOT for possible connections and add to the trans_table
-
-        Parameters
-        ----------
-        trans_table : pd.DataFrame
-            Table mapping supply curve points to transmission features.
-        fcr : float
-            Fixed charge rate, used to compute LCOT
-        trans_costs : str | dict | None
-            Transmission feature costs to use with TransmissionFeatures
-            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
-            center_tie_in_cost, sink_tie_in_cost
-        avail_cap_frac : int, optional
-            Fraction of transmissions features capacity 'ac_cap' to make
-            available for connection to supply curve points, by default 1
-        line_limited : bool
-            Substation connection is limited by maximum capacity of the
-            attached lines, legacy method
-        connectable : bool, optional
-            Flag to only compute tranmission capital cost if transmission
-            feature has enough available capacity, by default True
-        max_workers : int | NoneType
-            Number of workers to use to compute lcot, if > 1 run in parallel.
-            None uses all available cpu's.
-
-        Returns
-        -------
-        trans_table : pd.DataFrame
-            Same as input table but with new columns for trans_cap_cost_per_mw,
-            lcot, and total_lcoe.
-        """
-        if 'trans_cap_cost' not in trans_table:
-            cost = cls._compute_trans_cap_cost(trans_table,
-                                               trans_costs=trans_costs,
-                                               avail_cap_frac=avail_cap_frac,
-                                               line_limited=line_limited,
-                                               connectable=connectable,
-                                               max_workers=max_workers)
-            trans_table['trans_cap_cost_per_mw'] = cost  # $/MW
-        else:
-            cost = trans_table['trans_cap_cost'].values.copy()  # $
-            cost /= trans_table['capacity']  # $/MW
-            trans_table['trans_cap_cost_per_mw'] = cost
-
-        cf_mean_arr = trans_table['mean_cf'].values
-        lcot = (cost * fcr) / (cf_mean_arr * 8760)
-
-        trans_table['lcot'] = lcot
-        trans_table['total_lcoe'] = (trans_table['lcot']
-                                     + trans_table['mean_lcoe'])
-
-        return trans_table
-
     @staticmethod
     def _create_handler(trans_table, trans_costs=None, avail_cap_frac=1):
         """
@@ -527,7 +507,7 @@ class SupplyCurve:
 
     @staticmethod
     def _parse_sc_gids(trans_table, gid_key='sc_gid'):
-        """Filter the trans table, extract unique sc gids, make bool mask.
+        """Extract unique sc gids, make bool mask from tranmission table
 
         Parameters
         ----------
@@ -539,26 +519,56 @@ class SupplyCurve:
 
         Returns
         -------
-        trans_table : pd.DataFrame
-            Same as input but filtered to only include non-nan
-            supply curve gids.
         sc_gids : list
             List of unique integer supply curve gids (non-nan)
         mask : np.ndarray
             Boolean array initialized as true. Length is equal to the maximum
             SC gid so that the SC gids can be used to index the mask directly.
         """
-
-        filter_mask = ~pd.isna(trans_table[gid_key])
-        trans_table = trans_table[filter_mask]
         sc_gids = list(np.sort(trans_table[gid_key].unique()))
         sc_gids = [int(gid) for gid in sc_gids]
         mask = np.ones(int(1 + max(sc_gids)), dtype=bool)
 
-        return trans_table, sc_gids, mask
+        return sc_gids, mask
 
     @staticmethod
-    def _compute_trans_cap_cost(trans_table, trans_costs=None,
+    def _get_capacity(sc_gid, sc_table, connectable=True):
+        """
+        Get capacity of supply curve point
+
+        Parameters
+        ----------
+        sc_gid : int
+            Supply curve gid
+        sc_table : pandas.DataFrame
+            DataFrame of sc point to transmission features mapping for given
+            sc_gid
+        connectable : bool, optional
+            Flag to ensure SC point can connect to transmission features,
+            by default True
+
+        Returns
+        -------
+        capacity : float
+            Capacity of supply curve point
+        """
+        if connectable:
+            capacity = sc_table['capacity'].unique()
+            if len(capacity) == 1:
+                capacity = capacity[0]
+            else:
+                msg = ('Each supply curve point should only have '
+                       'a single capacity, but {} has {}'
+                       .format(sc_gid, capacity))
+                logger.error(msg)
+                raise RuntimeError(msg)
+        else:
+            capacity = None
+
+        return capacity
+
+    @classmethod
+    def _compute_trans_cap_cost(cls, trans_table, trans_costs=None,
                                 avail_cap_frac=1, max_workers=None,
                                 connectable=True, line_limited=False):
         """
@@ -612,26 +622,15 @@ class SupplyCurve:
             max_workers = os.cpu_count()
 
         logger.info('Computing LCOT costs for all possible connections...')
+        groups = trans_table.groupby('sc_gid')
         if max_workers > 1:
-            groups = trans_table.groupby('sc_gid')
             loggers = [__name__, 'reV.handlers.transmission', 'reV']
             with SpawnProcessPool(max_workers=max_workers,
                                   loggers=loggers) as exe:
                 futures = []
                 for sc_gid, sc_table in groups:
-                    if connectable:
-                        capacity = sc_table['capacity'].unique()
-                        if len(capacity) == 1:
-                            capacity = capacity[0]
-                        else:
-                            msg = ('Each supply curve point should only have '
-                                   'a single capacity, but {} has {}'
-                                   .format(sc_gid, capacity))
-                            logger.error(msg)
-                            raise RuntimeError(msg)
-                    else:
-                        capacity = None
-
+                    capacity = cls._get_capacity(sc_gid, sc_table,
+                                                 connectable=connectable)
                     futures.append(exe.submit(TC.feature_costs, sc_table,
                                               capacity=capacity,
                                               avail_cap_frac=avail_cap_frac,
@@ -639,34 +638,82 @@ class SupplyCurve:
                                               **trans_costs))
 
                 cost = [future.result() for future in futures]
-                cost = np.hstack(cost)
         else:
-            feature = TC(trans_table, line_limited=line_limited,
-                         **trans_costs)
             cost = []
-            for _, row in trans_table.iterrows():
-                if connectable:
-                    capacity = row['capacity']
-                else:
-                    capacity = None
-
-                tm = row.get('transmission_multiplier', 1)
-                cost.append(feature.cost(row['trans_gid'], row['dist_km'],
-                                         capacity=capacity,
-                                         transmission_multiplier=tm))
-
-            cost = np.array(cost, dtype='float32')
+            for sc_gid, sc_table in groups:
+                capacity = cls._get_capacity(sc_gid, sc_table,
+                                             connectable=connectable)
+                cost.append(TC.feature_costs(sc_table,
+                                             capacity=capacity,
+                                             avail_cap_frac=avail_cap_frac,
+                                             line_limited=line_limited,
+                                             **trans_costs))
 
+        cost = np.hstack(cost).astype('float32')
         logger.info('LCOT cost calculation is complete.')
 
         return cost
 
+    def compute_total_lcoe(self, fcr, transmission_costs=None,
+                           avail_cap_frac=1, line_limited=False,
+                           connectable=True, max_workers=None,
+                           consider_friction=True):
+        """
+        Compute LCOT and total LCOE for all sc point to transmission feature
+        connections
+
+        Parameters
+        ----------
+        fcr : float
+            Fixed charge rate, used to compute LCOT
+        transmission_costs : str | dict, optional
+            Transmission feature costs to use with TransmissionFeatures
+            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
+            center_tie_in_cost, sink_tie_in_cost, by default None
+        avail_cap_frac : int, optional
+            Fraction of transmissions features capacity 'ac_cap' to make
+            available for connection to supply curve points, by default 1
+        line_limited : bool, optional
+            Flag to have substation connection is limited by maximum capacity
+            of the attached lines, legacy method, by default False
+        connectable : bool, optional
+            Flag to only compute tranmission capital cost if transmission
+            feature has enough available capacity, by default True
+        max_workers : int | NoneType, optional
+            Number of workers to use to compute lcot, if > 1 run in parallel.
+            None uses all available cpu's. by default None
+        consider_friction : bool, optional
+            Flag to consider friction layer on LCOE when "mean_lcoe_friction"
+            is in the sc points input, by default True
+        """
+        if 'trans_cap_cost' not in self._trans_table:
+            cost = self._compute_trans_cap_cost(self._trans_table,
+                                                trans_costs=transmission_costs,
+                                                avail_cap_frac=avail_cap_frac,
+                                                line_limited=line_limited,
+                                                connectable=connectable,
+                                                max_workers=max_workers)
+            self._trans_table['trans_cap_cost_per_mw'] = cost  # $/MW
+        else:
+            cost = self._trans_table['trans_cap_cost'].values.copy()  # $
+            cost /= self._trans_table['capacity']  # $/MW
+            self._trans_table['trans_cap_cost_per_mw'] = cost
+
+        cf_mean_arr = self._trans_table['mean_cf'].values
+        lcot = (cost * fcr) / (cf_mean_arr * 8760)
+
+        self._trans_table['lcot'] = lcot
+        self._trans_table['total_lcoe'] = (self._trans_table['lcot']
+                                           + self._trans_table['mean_lcoe'])
+
+        if consider_friction:
+            self._calculate_total_lcoe_friction()
+
     def _calculate_total_lcoe_friction(self):
         """Look for site mean LCOE with friction in the trans table and if
         found make a total LCOE column with friction."""
 
-        if ('mean_lcoe_friction' in self._trans_table
-                and self._consider_friction):
+        if 'mean_lcoe_friction' in self._trans_table:
             lcoe_friction = (self._trans_table['lcot']
                              + self._trans_table['mean_lcoe_friction'])
             self._trans_table['total_lcoe_friction'] = lcoe_friction
@@ -749,7 +796,8 @@ class SupplyCurve:
 
         return table
 
-    def _full_sort(self, trans_table, comp_wind_dirs=None,
+    def _full_sort(self, trans_table, trans_costs=None,
+                   avail_cap_frac=1, comp_wind_dirs=None,
                    total_lcoe_fric=None, sort_on='total_lcoe',
                    columns=('trans_gid', 'trans_capacity', 'trans_type',
                             'trans_cap_cost_per_mw', 'dist_km', 'lcot',
@@ -762,6 +810,13 @@ class SupplyCurve:
         ----------
         trans_table : pandas.DataFrame
             Supply Curve Tranmission table to sort on
+        trans_costs : str | dict, optional
+            Transmission feature costs to use with TransmissionFeatures
+            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
+            center_tie_in_cost, sink_tie_in_cost, by default None
+        avail_cap_frac : int, optional
+            Fraction of transmissions features capacity 'ac_cap' to make
+            available for connection to supply curve points, by default 1
         comp_wind_dirs : CompetitiveWindFarms, optional
             Pre-initilized CompetitiveWindFarms instance, by default None
         total_lcoe_fric : ndarray, optional
@@ -785,6 +840,9 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT based on full supply curve connections
         """
+        trans_features = self._create_handler(self._trans_table,
+                                              trans_costs=trans_costs,
+                                              avail_cap_frac=avail_cap_frac)
         init_list = [np.nan] * int(1 + np.max(self._sc_gids))
         conn_lists = {k: deepcopy(init_list) for k in columns}
 
@@ -804,8 +862,7 @@ class SupplyCurve:
             sc_gid = trans_sc_gids[i]
             if self._mask[sc_gid]:
                 trans_gid = trans_gids[i]
-                connect = self._trans_features.connect(trans_gid,
-                                                       capacities[i])
+                connect = trans_features.connect(trans_gid, capacities[i])
                 if connect:
                     connected += 1
                     logger.debug('Connecting sc gid {}'.format(sc_gid))
@@ -860,17 +917,20 @@ class SupplyCurve:
 
         return supply_curve.reset_index(drop=True)
 
-    def _check_feature_capacity(self):
+    def _check_feature_capacity(self, avail_cap_frac=1):
         """
         Add the transmission connection feature capacity to the trans table if
         needed
         """
         if 'avail_cap' not in self._trans_table:
-            kwargs = {'avail_cap_frac': self._avail_cap_frac}
+            kwargs = {'avail_cap_frac': avail_cap_frac}
             fc = TF.feature_capacity(self._trans_table, **kwargs)
             self._trans_table = self._trans_table.merge(fc, on='trans_gid')
 
-    def full_sort(self, sort_on='total_lcoe',
+    def full_sort(self, fcr, transmission_costs=None,
+                  avail_cap_frac=1, line_limited=False,
+                  connectable=True, max_workers=None,
+                  consider_friction=True, sort_on='total_lcoe',
                   columns=('trans_gid', 'trans_capacity', 'trans_type',
                            'trans_cap_cost_per_mw', 'dist_km', 'lcot',
                            'total_lcoe'),
@@ -881,16 +941,40 @@ class SupplyCurve:
 
         Parameters
         ----------
-        sort_on : str
+        fcr : float
+            Fixed charge rate, used to compute LCOT
+        transmission_costs : str | dict, optional
+            Transmission feature costs to use with TransmissionFeatures
+            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
+            center_tie_in_cost, sink_tie_in_cost, by default None
+        avail_cap_frac : int, optional
+            Fraction of transmissions features capacity 'ac_cap' to make
+            available for connection to supply curve points, by default 1
+        line_limited : bool, optional
+            Flag to have substation connection is limited by maximum capacity
+            of the attached lines, legacy method, by default False
+        connectable : bool, optional
+            Flag to only compute tranmission capital cost if transmission
+            feature has enough available capacity, by default True
+        max_workers : int | NoneType, optional
+            Number of workers to use to compute lcot, if > 1 run in parallel.
+            None uses all available cpu's. by default None
+        consider_friction : bool, optional
+            Flag to consider friction layer on LCOE when "mean_lcoe_friction"
+            is in the sc points input, by default True
+        sort_on : str, optional
             Column label to sort the Supply Curve table on. This affects the
             build priority - connections with the lowest value in this column
-            will be built first.
-        columns : list | tuple
-            Columns to preserve in output connections dataframe.
-        wind_dirs : pandas.DataFrame | str
+            will be built first, by default 'total_lcoe'
+        columns : list | tuple, optional
+            Columns to preserve in output connections dataframe,
+            by default ('trans_gid', 'trans_capacity', 'trans_type',
+                        'trans_cap_cost_per_mw', 'dist_km', 'lcot',
+                        'total_lcoe')
+        wind_dirs : pandas.DataFrame | str, optional
             path to .csv or reVX.wind_dirs.wind_dirs.WindDirs output with
             the neighboring supply curve point gids and power-rose value at
-            each cardinal direction
+            each cardinal direction, by default None
         n_dirs : int, optional
             Number of prominent directions to use, by default 2
         downwind : bool, optional
@@ -906,8 +990,14 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT based on full supply curve connections
         """
-        self._trans_features.check_feature_dependencies()
-        self._check_feature_capacity()
+        self._check_substation_conns(self._trans_table)
+        self.compute_total_lcoe(fcr, transmission_costs=transmission_costs,
+                                avail_cap_frac=avail_cap_frac,
+                                line_limited=line_limited,
+                                connectable=connectable,
+                                max_workers=max_workers,
+                                consider_friction=consider_friction)
+        self._check_feature_capacity(avail_cap_frac=avail_cap_frac)
 
         if isinstance(columns, tuple):
             columns = list(columns)
@@ -917,7 +1007,7 @@ class SupplyCurve:
         trans_table = trans_table.loc[~pos].sort_values(sort_on)
 
         total_lcoe_fric = None
-        if self._consider_friction and 'mean_lcoe_friction' in trans_table:
+        if consider_friction and 'mean_lcoe_friction' in trans_table:
             columns.append('total_lcoe_friction')
             total_lcoe_fric = trans_table['total_lcoe_friction'].values
 
@@ -939,6 +1029,8 @@ class SupplyCurve:
                                                   offshore=offshore_compete)
 
         supply_curve = self._full_sort(trans_table,
+                                       trans_costs=transmission_costs,
+                                       avail_cap_frac=avail_cap_frac,
                                        comp_wind_dirs=comp_wind_dirs,
                                        total_lcoe_fric=total_lcoe_fric,
                                        sort_on=sort_on, columns=columns,
@@ -946,7 +1038,9 @@ class SupplyCurve:
 
         return supply_curve
 
-    def simple_sort(self, sort_on='total_lcoe',
+    def simple_sort(self, fcr, transmission_costs=None,
+                    avail_cap_frac=1, max_workers=None,
+                    consider_friction=True, sort_on='total_lcoe',
                     columns=('trans_gid', 'trans_type', 'lcot', 'total_lcoe',
                              'trans_cap_cost_per_mw'),
                     wind_dirs=None, n_dirs=2, downwind=False,
@@ -957,16 +1051,40 @@ class SupplyCurve:
 
         Parameters
         ----------
-        sort_on : str
+        fcr : float
+            Fixed charge rate, used to compute LCOT
+        transmission_costs : str | dict, optional
+            Transmission feature costs to use with TransmissionFeatures
+            handler: line_tie_in_cost, line_cost, station_tie_in_cost,
+            center_tie_in_cost, sink_tie_in_cost, by default None
+        avail_cap_frac : int, optional
+            Fraction of transmissions features capacity 'ac_cap' to make
+            available for connection to supply curve points, by default 1
+        line_limited : bool, optional
+            Flag to have substation connection is limited by maximum capacity
+            of the attached lines, legacy method, by default False
+        connectable : bool, optional
+            Flag to only compute tranmission capital cost if transmission
+            feature has enough available capacity, by default True
+        max_workers : int | NoneType, optional
+            Number of workers to use to compute lcot, if > 1 run in parallel.
+            None uses all available cpu's. by default None
+        consider_friction : bool, optional
+            Flag to consider friction layer on LCOE when "mean_lcoe_friction"
+            is in the sc points input, by default True
+        sort_on : str, optional
             Column label to sort the Supply Curve table on. This affects the
             build priority - connections with the lowest value in this column
-            will be built first.
-        columns : list | tuple
-            Columns to preserve in output connections dataframe.
-        wind_dirs : pandas.DataFrame | str
+            will be built first, by default 'total_lcoe'
+        columns : list | tuple, optional
+            Columns to preserve in output connections dataframe,
+            by default ('trans_gid', 'trans_capacity', 'trans_type',
+                        'trans_cap_cost_per_mw', 'dist_km', 'lcot',
+                        'total_lcoe')
+        wind_dirs : pandas.DataFrame | str, optional
             path to .csv or reVX.wind_dirs.wind_dirs.WindDirs output with
             the neighboring supply curve point gids and power-rose value at
-            each cardinal direction
+            each cardinal direction, by default None
         n_dirs : int, optional
             Number of prominent directions to use, by default 2
         downwind : bool, optional
@@ -981,12 +1099,17 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT based on simple supply curve connections
         """
+        self.compute_total_lcoe(fcr, transmission_costs=transmission_costs,
+                                avail_cap_frac=avail_cap_frac,
+                                connectable=False,
+                                max_workers=max_workers,
+                                consider_friction=consider_friction)
         trans_table = self._trans_table.copy()
 
         if isinstance(columns, tuple):
             columns = list(columns)
 
-        if self._consider_friction and 'total_lcoe_friction' in trans_table:
+        if consider_friction and 'total_lcoe_friction' in trans_table:
             columns.append('total_lcoe_friction')
 
         connections = trans_table.sort_values(sort_on).groupby('sc_gid')
@@ -1013,7 +1136,7 @@ class SupplyCurve:
     @classmethod
     def full(cls, sc_points, trans_table, fcr, sc_features=None,
              transmission_costs=None, avail_cap_frac=1,
-             line_limited=False, sort_on='total_lcoe',
+             line_limited=False, consider_friction=True, sort_on='total_lcoe',
              columns=('trans_gid', 'trans_capacity', 'trans_type',
                       'trans_cap_cost_per_mw', 'dist_km', 'lcot',
                       'total_lcoe'),
@@ -1047,6 +1170,9 @@ class SupplyCurve:
         line_limited : bool, optional
             Flag to have substation connection is limited by maximum capacity
             of the attached lines, legacy method, by default False
+        consider_friction : bool, optional
+            Flag to consider friction layer on LCOE when "mean_lcoe_friction"
+            is in the sc points input, by default True
         sort_on : str
             Column label to sort the Supply Curve table on. This affects the
             build priority - connections with the lowest value in this column
@@ -1074,11 +1200,13 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT
         """
-        sc = cls(sc_points, trans_table, fcr, sc_features=sc_features,
-                 transmission_costs=transmission_costs,
-                 avail_cap_frac=avail_cap_frac, line_limited=line_limited,
-                 max_workers=max_workers)
-        supply_curve = sc.full_sort(sort_on=sort_on, columns=columns,
+        sc = cls(sc_points, trans_table, sc_features=sc_features)
+        supply_curve = sc.full_sort(fcr, transmission_costs=transmission_costs,
+                                    avail_cap_frac=avail_cap_frac,
+                                    line_limited=line_limited,
+                                    max_workers=max_workers,
+                                    consider_friction=consider_friction,
+                                    sort_on=sort_on, columns=columns,
                                     wind_dirs=wind_dirs, n_dirs=n_dirs,
                                     downwind=downwind,
                                     offshore_compete=offshore_compete)
@@ -1087,7 +1215,8 @@ class SupplyCurve:
 
     @classmethod
     def simple(cls, sc_points, trans_table, fcr, sc_features=None,
-               transmission_costs=None, sort_on='total_lcoe',
+               transmission_costs=None, consider_friction=True,
+               sort_on='total_lcoe',
                columns=('trans_gid', 'trans_type', 'lcot', 'total_lcoe',
                         'dist_km', 'trans_cap_cost_per_mw'),
                max_workers=None, wind_dirs=None, n_dirs=2, downwind=False,
@@ -1113,6 +1242,9 @@ class SupplyCurve:
             Transmission feature costs to use with TransmissionFeatures
             handler: line_tie_in_cost, line_cost, station_tie_in_cost,
             center_tie_in_cost, sink_tie_in_cost
+        consider_friction : bool, optional
+            Flag to consider friction layer on LCOE when "mean_lcoe_friction"
+            is in the sc points input, by default True
         sort_on : str
             Column label to sort the Supply Curve table on. This affects the
             build priority - connections with the lowest value in this column
@@ -1140,10 +1272,12 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT
         """
-        sc = cls(sc_points, trans_table, fcr, sc_features=sc_features,
-                 transmission_costs=transmission_costs, connectable=False,
-                 max_workers=max_workers)
-        supply_curve = sc.simple_sort(sort_on=sort_on, columns=columns,
+        sc = cls(sc_points, trans_table, sc_features=sc_features)
+        supply_curve = sc.simple_sort(fcr,
+                                      transmission_costs=transmission_costs,
+                                      max_workers=max_workers,
+                                      consider_friction=consider_friction,
+                                      sort_on=sort_on, columns=columns,
                                       wind_dirs=wind_dirs, n_dirs=n_dirs,
                                       downwind=downwind,
                                       offshore_compete=offshore_compete)
